@@ -4,7 +4,7 @@ LSP::DidCloseTextDocumentRequest::DidCloseTextDocumentRequest(const wxFileName&
 {
     SetMethod("textDocument/didClose");
     m_params.reset(new DidCloseTextDocumentParams());
-    m_params->As<DidCloseTextDocumentParams>()->SetTextDocument(TextDocumentIdentifier(filename));
+    m_params->As<DidCloseTextDocumentParams>()->SetTextDocument(TextDocumentIdentifier(filename.GetFullPath()));
 }
 
 LSP::DidCloseTextDocumentRequest::~DidCloseTextDocumentRequest() {}
