@@ -6,7 +6,8 @@ LSP::DidOpenTextDocumentRequest::DidOpenTextDocumentRequest(const wxFileName& fi
 {
     SetMethod("textDocument/didOpen");
     m_params.reset(new DidOpenTextDocumentParams());
-    m_params->As<DidOpenTextDocumentParams>()->SetTextDocument(TextDocumentItem(filename, langugage, text));
+    m_params->As<DidOpenTextDocumentParams>()->SetTextDocument(
+        TextDocumentItem(filename.GetFullPath(), langugage, text));
 }
 
 LSP::DidOpenTextDocumentRequest::~DidOpenTextDocumentRequest() {}
