@@ -25,12 +25,12 @@
 
 #if USE_SFTP
 #include "cl_sftp.h"
-#include <wx/ffile.h>
+#include "cl_standard_paths.h"
+#include <libssh/sftp.h>
 #include <string.h>
 #include <sys/stat.h>
+#include <wx/ffile.h>
 #include <wx/filefn.h>
-#include <libssh/sftp.h>
-#include "cl_standard_paths.h"
 
 class SFTPDirCloser
 {
@@ -58,7 +58,9 @@ clSFTP::~clSFTP() { Close(); }
  */
 static void clSFTPReadLink(SFTPAttribute::Ptr_t attr, SFTPSession_t sftp, const wxString& curdir)
 {
-    if(!attr->IsSymlink()) { return; }
+    if(!attr->IsSymlink()) {
+        return;
+    }
     // build the symlink full path and read the target path
     wxString symlinkPath = curdir + "/" + attr->GetName();
     const char* target_path = sftp_readlink(sftp, symlinkPath.mb_str(wxConvUTF8).data());
@@ -73,15 +75,20 @@ static void clSFTPReadLink(SFTPAttribute::Ptr_t attr, SFTPSession_t sftp, const
         sftp_attributes linkattr = sftp_stat(sftp, targetPath.mb_str(wxConvUTF8).data());
         if(linkattr) {
             SFTPAttribute::Ptr_t targetAttr(new SFTPAttribute(linkattr));
-            if(targetAttr->IsFile()) { attr->SetFile(); }
-            if(targetAttr->IsFolder()) { attr->SetFolder(); }
+            if(targetAttr->IsFile()) {
+                attr->SetFile();
+            }
+            if(targetAttr->IsFolder()) {
+                attr->SetFolder();
+            }
         }
     }
 }
 
 void clSFTP::Initialize()
 {
-    if(m_sftp) return;
+    if(m_sftp)
+        return;
 
     m_sftp = sftp_new(m_ssh->GetSession());
     if(m_sftp == NULL) {
@@ -98,15 +105,19 @@ void clSFTP::Initialize()
 
 void clSFTP::Close()
 {
-    if(m_sftp) { sftp_free(m_sftp); }
+    if(m_sftp) {
+        sftp_free(m_sftp);
+    }
 
     m_connected = false;
     m_sftp = NULL;
 }
 
-void clSFTP::Write(const wxFileName& localFile, const wxString& remotePath, SFTPAttribute::Ptr_t attributes)
+void clSFTP::Write(const wxFileName& localFile, const wxString& remotePath)
 {
-    if(!m_connected) { throw clException("scp is not initialized!"); }
+    if(!m_connected) {
+        throw clException("scp is not initialized!");
+    }
 
     if(!localFile.Exists()) {
         throw clException(wxString() << "scp::Write file '" << localFile.GetFullPath() << "' does not exist!");
@@ -123,17 +134,19 @@ void clSFTP::Write(const wxFileName& localFile, const wxString& remotePath, SFTP
     size_t nbytes(0);
     while(!fp.Eof()) {
         nbytes = fp.Read(buffer, sizeof(buffer));
-        if(nbytes == 0) break;
+        if(nbytes == 0)
+            break;
         memBuffer.AppendData(buffer, nbytes);
     }
     fp.Close();
     Write(memBuffer, remotePath);
-    if(attributes && attributes->GetPermissions()) { Chmod(remotePath, attributes->GetPermissions()); }
 }
 
-void clSFTP::Write(const wxMemoryBuffer& fileContent, const wxString& remotePath, SFTPAttribute::Ptr_t attributes)
+void clSFTP::Write(const wxMemoryBuffer& fileContent, const wxString& remotePath)
 {
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
     int access_type = O_WRONLY | O_CREAT | O_TRUNC;
     sftp_file file;
@@ -166,17 +179,9 @@ void clSFTP::Write(const wxMemoryBuffer& fileContent, const wxString& remotePath
     sftp_close(file);
 
     // Unlink the original file if it exists
-    bool needUnlink = false;
-    {
-        // Check if the file exists
-        sftp_attributes attr = sftp_stat(m_sftp, remotePath.mb_str(wxConvISO8859_1).data());
-        if(attr) {
-            needUnlink = true;
-            sftp_attributes_free(attr);
-        }
-    }
+    SFTPAttribute::Ptr_t pattr(new SFTPAttribute(sftp_stat(m_sftp, remotePath.mb_str(wxConvISO8859_1).data())));
 
-    if(needUnlink && sftp_unlink(m_sftp, remotePath.mb_str(wxConvUTF8).data()) < 0) {
+    if(pattr->IsOk() && sftp_unlink(m_sftp, remotePath.mb_str(wxConvUTF8).data()) < 0) {
         throw clException(wxString() << _("Failed to unlink file: ") << remotePath << ". "
                                      << ssh_get_error(m_ssh->GetSession()),
                           sftp_get_error(m_sftp));
@@ -189,7 +194,9 @@ void clSFTP::Write(const wxMemoryBuffer& fileContent, const wxString& remotePath
                           sftp_get_error(m_sftp));
     }
 
-    if(attributes && attributes->GetPermissions()) { Chmod(remotePath, attributes->GetPermissions()); }
+    if(pattr->IsOk()) {
+        Chmod(remotePath, pattr->GetPermissions());
+    }
 }
 
 SFTPAttribute::List_t clSFTP::List(const wxString& folder, size_t flags, const wxString& filter)
@@ -197,7 +204,9 @@ SFTPAttribute::List_t clSFTP::List(const wxString& folder, size_t flags, const w
     sftp_dir dir;
     sftp_attributes attributes;
 
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
     dir = sftp_opendir(m_sftp, folder.mb_str(wxConvUTF8).data());
     if(!dir) {
@@ -216,7 +225,9 @@ SFTPAttribute::List_t clSFTP::List(const wxString& folder, size_t flags, const w
     attributes = sftp_readdir(m_sftp, dir);
     while(attributes) {
         SFTPAttribute::Ptr_t attr(new SFTPAttribute(attributes));
-        if(attr->IsSymlink()) { clSFTPReadLink(attr, m_sftp, m_currentFolder); }
+        if(attr->IsSymlink()) {
+            clSFTPReadLink(attr, m_sftp, m_currentFolder);
+        }
         attributes = sftp_readdir(m_sftp, dir);
 
         // Don't show files ?
@@ -251,7 +262,9 @@ SFTPAttribute::List_t clSFTP::CdUp(size_t flags, const wxString& filter)
 
 SFTPAttribute::Ptr_t clSFTP::Read(const wxString& remotePath, wxMemoryBuffer& buffer)
 {
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
     sftp_file file = sftp_open(m_sftp, remotePath.mb_str(wxConvUTF8).data(), O_RDONLY, 0);
     if(file == NULL) {
@@ -267,7 +280,8 @@ SFTPAttribute::Ptr_t clSFTP::Read(const wxString& remotePath, wxMemoryBuffer& bu
                           sftp_get_error(m_sftp));
     }
     wxInt64 fileSize = fileAttr->GetSize();
-    if(fileSize == 0) return fileAttr;
+    if(fileSize == 0)
+        return fileAttr;
 
     // Allocate buffer for the file content
     char pBuffer[65536]; // buffer
@@ -295,7 +309,9 @@ SFTPAttribute::Ptr_t clSFTP::Read(const wxString& remotePath, wxMemoryBuffer& bu
 
 void clSFTP::CreateDir(const wxString& dirname)
 {
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
     int rc;
     rc = sftp_mkdir(m_sftp, dirname.mb_str(wxConvISO8859_1).data(), S_IRWXU);
@@ -309,7 +325,9 @@ void clSFTP::CreateDir(const wxString& dirname)
 
 void clSFTP::Rename(const wxString& oldpath, const wxString& newpath)
 {
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
     int rc;
     rc = sftp_rename(m_sftp, oldpath.mb_str(wxConvISO8859_1).data(), newpath.mb_str(wxConvISO8859_1).data());
@@ -322,7 +340,9 @@ void clSFTP::Rename(const wxString& oldpath, const wxString& newpath)
 
 void clSFTP::RemoveDir(const wxString& dirname)
 {
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
     int rc;
     rc = sftp_rmdir(m_sftp, dirname.mb_str(wxConvISO8859_1).data());
@@ -336,7 +356,9 @@ void clSFTP::RemoveDir(const wxString& dirname)
 
 void clSFTP::UnlinkFile(const wxString& path)
 {
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
     int rc;
     rc = sftp_unlink(m_sftp, path.mb_str(wxConvISO8859_1).data());
@@ -350,7 +372,9 @@ void clSFTP::UnlinkFile(const wxString& path)
 
 SFTPAttribute::Ptr_t clSFTP::Stat(const wxString& path)
 {
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
     sftp_attributes attr = sftp_stat(m_sftp, path.mb_str(wxConvISO8859_1).data());
     if(!attr) {
@@ -367,24 +391,30 @@ SFTPAttribute::Ptr_t clSFTP::Stat(const wxString& path)
         target = ctarget;
     }
     SFTPAttribute::Ptr_t pattr(new SFTPAttribute(attr));
-    if(attr->type == SSH_FILEXFER_TYPE_SYMLINK) { pattr->SetSymlinkPath(target); }
+    if(attr->type == SSH_FILEXFER_TYPE_SYMLINK) {
+        pattr->SetSymlinkPath(target);
+    }
     return pattr;
 }
 
-void clSFTP::CreateRemoteFile(const wxString& remoteFullPath, const wxString& content, SFTPAttribute::Ptr_t attr)
+void clSFTP::CreateRemoteFile(const wxString& remoteFullPath, const wxString& content)
 {
     // Create the path to the file
     Mkpath(wxFileName(remoteFullPath).GetPath());
-    Write(content, remoteFullPath, attr);
+    Write(content, remoteFullPath);
 }
 
 void clSFTP::Mkpath(const wxString& remoteDirFullpath)
 {
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
     wxString tmpPath = remoteDirFullpath;
     tmpPath.Replace("\\", "/");
-    if(!tmpPath.StartsWith("/")) { throw clException("Mkpath: path must be absolute"); }
+    if(!tmpPath.StartsWith("/")) {
+        throw clException("Mkpath: path must be absolute");
+    }
 
     wxFileName fn(remoteDirFullpath, "");
     const wxArrayString& dirs = fn.GetDirs();
@@ -406,17 +436,20 @@ void clSFTP::Mkpath(const wxString& remoteDirFullpath)
     }
 }
 
-void clSFTP::CreateRemoteFile(const wxString& remoteFullPath, const wxFileName& localFile, SFTPAttribute::Ptr_t attr)
+void clSFTP::CreateRemoteFile(const wxString& remoteFullPath, const wxFileName& localFile)
 {
     Mkpath(wxFileName(remoteFullPath).GetPath());
-    Write(localFile, remoteFullPath, attr);
+    Write(localFile, remoteFullPath);
 }
 
 void clSFTP::Chmod(const wxString& remotePath, size_t permissions)
 {
-    if(!m_sftp) { throw clException("SFTP is not initialized"); }
+    if(!m_sftp) {
+        throw clException("SFTP is not initialized");
+    }
 
-    if(permissions == 0) return;
+    if(permissions == 0)
+        return;
 
     int rc = sftp_chmod(m_sftp, remotePath.mb_str(wxConvUTF8).data(), permissions);
     if(rc != SSH_OK) {
@@ -426,12 +459,32 @@ void clSFTP::Chmod(const wxString& remotePath, size_t permissions)
     }
 }
 
-wxString clSFTP::GetDefaultDownloadFolder()
+wxString clSFTP::GetDefaultDownloadFolder(const SSHAccountInfo& accountInfo)
 {
     wxFileName path(clStandardPaths::Get().GetUserDataDir(), "");
     path.AppendDir("sftp");
-    path.AppendDir("tmp");
+    path.AppendDir("download");
+    if(!accountInfo.GetHost().empty()) {
+        path.AppendDir(accountInfo.GetHost());
+    }
     return path.GetPath();
 }
 
+wxFileName clSFTP::GetLocalFileName(const SSHAccountInfo& accountInfo, const wxString& remotePath, bool mkdirRecrusive)
+{
+    // Generate a temporary file location
+    wxFileName fnRemoteFile(remotePath);
+    wxFileName localFile(GetDefaultDownloadFolder(accountInfo), fnRemoteFile.GetFullName());
+    const wxArrayString& dirs = fnRemoteFile.GetDirs();
+    for(size_t i = 0; i < dirs.GetCount(); ++i) {
+        localFile.AppendDir(dirs.Item(i));
+    }
+
+    if(mkdirRecrusive) {
+        // Ensure that the path to the sftp temp folder exists
+        localFile.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
+    }
+    return localFile.GetFullPath();
+}
+
 #endif // USE_SFTP
