@@ -131,7 +131,9 @@ void CompilerMainPage::OnBtnAddWarnPattern(wxCommandEvent& event)
 void CompilerMainPage::OnBtnDelErrPattern(wxCommandEvent& event)
 {
     int sel = m_listErrPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if(sel == wxNOT_FOUND) { return; }
+    if(sel == wxNOT_FOUND) {
+        return;
+    }
     m_listErrPatterns->DeleteItem(sel);
     m_isDirty = true;
 }
@@ -139,7 +141,9 @@ void CompilerMainPage::OnBtnDelErrPattern(wxCommandEvent& event)
 void CompilerMainPage::OnBtnDelWarnPattern(wxCommandEvent& event)
 {
     int sel = m_listWarnPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if(sel == wxNOT_FOUND) { return; }
+    if(sel == wxNOT_FOUND) {
+        return;
+    }
     m_listWarnPatterns->DeleteItem(sel);
     m_isDirty = true;
 }
@@ -147,7 +151,9 @@ void CompilerMainPage::OnBtnDelWarnPattern(wxCommandEvent& event)
 void CompilerMainPage::OnBtnUpdateErrPattern(wxCommandEvent& event)
 {
     int sel = m_listErrPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if(sel == wxNOT_FOUND) { return; }
+    if(sel == wxNOT_FOUND) {
+        return;
+    }
     DoUpdateErrPattern(sel);
     m_isDirty = true;
 }
@@ -155,14 +161,18 @@ void CompilerMainPage::OnBtnUpdateErrPattern(wxCommandEvent& event)
 void CompilerMainPage::OnBtnUpdateWarnPattern(wxCommandEvent& event)
 {
     int sel = m_listWarnPatterns->GetNextItem(-1, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-    if(sel == wxNOT_FOUND) { return; }
+    if(sel == wxNOT_FOUND) {
+        return;
+    }
     DoUpdateWarnPattern(sel);
     m_isDirty = true;
 }
 
 void CompilerMainPage::OnCompilerOptionActivated(wxListEvent& event)
 {
-    if(m_selectedCmpOption == wxNOT_FOUND) { return; }
+    if(m_selectedCmpOption == wxNOT_FOUND) {
+        return;
+    }
 
     wxString name = m_listCompilerOptions->GetItemText(m_selectedCmpOption);
     wxString help = GetColumnText(m_listCompilerOptions, m_selectedCmpOption, 1);
@@ -220,9 +230,13 @@ void CompilerMainPage::OnDeleteCompilerOption(wxCommandEvent& event)
 
 void CompilerMainPage::OnDeleteFileType(wxCommandEvent& event)
 {
-    if(m_dvListCtrlFileTemplates->GetSelectedItemsCount() == 0) { return; }
+    if(m_dvListCtrlFileTemplates->GetSelectedItemsCount() == 0) {
+        return;
+    }
     int sel = m_dvListCtrlFileTemplates->GetSelectedRow();
-    if(sel == wxNOT_FOUND) { return; }
+    if(sel == wxNOT_FOUND) {
+        return;
+    }
     wxDataViewItem item = m_dvListCtrlFileTemplates->RowToItem(sel);
     wxString filetype = m_dvListCtrlFileTemplates->GetItemText(item);
 
@@ -318,7 +332,9 @@ void CompilerMainPage::DoUpdateErrPattern(long item)
 
 void CompilerMainPage::DoFileTypeActivated(const wxDataViewItem& item)
 {
-    if(!item.IsOk()) { return; }
+    if(!item.IsOk()) {
+        return;
+    }
 
     NewFileTemplateDialog dlg(wxGetTopLevelParent(this));
     wxString ext = m_dvListCtrlFileTemplates->GetItemText(item, 0);
@@ -348,10 +364,14 @@ void CompilerMainPage::OnItemActivated(wxListEvent& event)
     info.m_col = 0; // name
     info.m_mask = wxLIST_MASK_TEXT;
 
-    if(m_listSwitches->GetItem(info)) { m_selSwitchName = info.m_text; }
+    if(m_listSwitches->GetItem(info)) {
+        m_selSwitchName = info.m_text;
+    }
 
     info.m_col = 1; // value
-    if(m_listSwitches->GetItem(info)) { m_selSwitchValue = info.m_text; }
+    if(m_listSwitches->GetItem(info)) {
+        m_selSwitchValue = info.m_text;
+    }
     EditSwitch();
 }
 
@@ -364,15 +384,21 @@ void CompilerMainPage::OnItemSelected(wxListEvent& event)
     info.m_col = 0; // name
     info.m_mask = wxLIST_MASK_TEXT;
 
-    if(m_listSwitches->GetItem(info)) { m_selSwitchName = info.m_text; }
+    if(m_listSwitches->GetItem(info)) {
+        m_selSwitchName = info.m_text;
+    }
 
     info.m_col = 1; // value
-    if(m_listSwitches->GetItem(info)) { m_selSwitchValue = info.m_text; }
+    if(m_listSwitches->GetItem(info)) {
+        m_selSwitchValue = info.m_text;
+    }
 }
 
 void CompilerMainPage::OnLinkerOptionActivated(wxListEvent& event)
 {
-    if(m_selectedLnkOption == wxNOT_FOUND) { return; }
+    if(m_selectedLnkOption == wxNOT_FOUND) {
+        return;
+    }
 
     wxString name = m_listLinkerOptions->GetItemText(m_selectedLnkOption);
     wxString help = GetColumnText(m_listLinkerOptions, m_selectedLnkOption, 1);
@@ -476,7 +502,9 @@ void CompilerMainPage::InitializePatterns()
 void CompilerMainPage::LoadCompiler(const wxString& compilerName)
 {
     // Save before we switch
-    if(m_isDirty) { Save(); }
+    if(m_isDirty) {
+        Save();
+    }
     m_compiler = BuildSettingsConfigST::Get()->GetCompiler(compilerName);
 
     // Start initialization
@@ -561,6 +589,7 @@ void CompilerMainPage::Initialize()
 
 void CompilerMainPage::Save()
 {
+    CHECK_PTR_RET(m_compiler);
     SaveTools();
     SavePatterns();
     SaveSwitches();
@@ -785,7 +814,9 @@ void CompilerMainPage::LoadCompilers()
     wxString cmpType;
     if(clCxxWorkspaceST::Get()->IsOpen() && clCxxWorkspaceST::Get()->GetActiveProject()) {
         BuildConfigPtr bldConf = clCxxWorkspaceST::Get()->GetActiveProject()->GetBuildConfiguration();
-        if(bldConf) { cmpType = bldConf->GetCompilerType(); }
+        if(bldConf) {
+            cmpType = bldConf->GetCompilerType();
+        }
     }
 
     BuildSettingsConfigCookie cookie;
@@ -793,7 +824,9 @@ void CompilerMainPage::LoadCompilers()
     int sel(0);
     while(cmp) {
         int curidx = m_listBoxCompilers->Append(cmp->GetName());
-        if(!cmpType.IsEmpty() && (cmp->GetName() == cmpType)) { sel = curidx; }
+        if(!cmpType.IsEmpty() && (cmp->GetName() == cmpType)) {
+            sel = curidx;
+        }
         cmp = BuildSettingsConfigST::Get()->GetNextCompiler(cookie);
     }
 
@@ -856,7 +889,8 @@ void CompilerMainPage::OnContextMenu(wxContextMenuEvent& event)
 void CompilerMainPage::OnDeleteCompiler(wxCommandEvent& event)
 {
     int selection = m_listBoxCompilers->GetSelection();
-    if(selection == wxNOT_FOUND) return;
+    if(selection == wxNOT_FOUND)
+        return;
 
     if(::wxMessageBox(wxString() << _("Are you sure you want to delete compiler\n'")
                                  << m_listBoxCompilers->GetStringSelection() << "'?",
@@ -873,14 +907,17 @@ void CompilerMainPage::OnDeleteCompiler(wxCommandEvent& event)
 void CompilerMainPage::OnRenameCompiler(wxCommandEvent& event)
 {
     int selection = m_listBoxCompilers->GetSelection();
-    if(selection == wxNOT_FOUND) return;
+    if(selection == wxNOT_FOUND)
+        return;
 
     wxString newName =
         ::wxGetTextFromUser(_("New Compiler Name"), _("Rename Compiler"), m_listBoxCompilers->GetStringSelection());
-    if(newName.IsEmpty()) return;
+    if(newName.IsEmpty())
+        return;
 
     CompilerPtr compiler = BuildSettingsConfigST::Get()->GetCompiler(m_listBoxCompilers->GetStringSelection());
-    if(!compiler) return;
+    if(!compiler)
+        return;
 
     // Delete the old compiler
     BuildSettingsConfigST::Get()->DeleteCompiler(compiler->GetName());
