@@ -22,40 +22,44 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+#include "ColoursAndFontsManager.h"
 #include "FindInFilesLocationsDlg.h"
 #include "clWorkspaceManager.h"
 #include "dirpicker.h"
 #include "findinfilesdlg.h"
 #include "findresultstab.h"
 #include "frame.h"
+#include "globals.h"
+#include "lexer_configuration.h"
 #include "macros.h"
 #include "manager.h"
 #include "replaceinfilespanel.h"
 #include "search_thread.h"
+#include "sessionmanager.h"
 #include "windowattrmanager.h"
+#include "workspace.h"
 #include <algorithm>
+#include <project.h>
 #include <wx/fontmap.h>
 #include <wx/tokenzr.h>
-#include "sessionmanager.h"
-#include "workspace.h"
-#include <project.h>
-#include "lexer_configuration.h"
-#include "ColoursAndFontsManager.h"
-#include "globals.h"
 #include <wx/wupdlock.h>
+#include <wxStringHash.h>
 
 FindInFilesDialog::FindInFilesDialog(wxWindow* parent, FindReplaceData& data)
     : FindInFilesDialogBase(parent, wxID_ANY)
     , m_data(data)
 {
-    wxWindowUpdateLocker locker(this);
     LexerConf::Ptr_t lexer = ColoursAndFontsManager::Get().GetLexer("text");
-    if(lexer) { lexer->Apply(m_stcPaths); }
+    if(lexer) {
+        lexer->Apply(m_stcPaths);
+    }
     m_stcPaths->SetEOLMode(wxSTC_EOL_LF);
 
     // Store the find-in-files data
     wxString filemask = SessionManager::Get().GetFindInFilesMaskForCurrentWorkspace();
-    if(!filemask.IsEmpty()) { m_data.SetSelectedMask(filemask); }
+    if(!filemask.IsEmpty()) {
+        m_data.SetSelectedMask(filemask);
+    }
     DoSetSearchPaths(m_data.GetSearchPaths());
 
     // Search for
@@ -71,25 +75,36 @@ FindInFilesDialog::FindInFilesDialog(wxWindow* parent, FindReplaceData& data)
     m_regualrExpression->SetValue(m_data.GetFlags() & wxFRD_REGULAREXPRESSION);
     m_checkBoxSaveFilesBeforeSearching->SetValue(m_data.GetFlags() & wxFRD_SAVE_BEFORE_SEARCH);
     m_checkBoxPipeForGrep->SetValue(m_data.GetFlags() & wxFRD_ENABLE_PIPE_SUPPORT);
+
     // Set encoding
-    wxArrayString astrEncodings;
-    wxFontEncoding fontEnc;
-    int selection(0);
+    static wxArrayString astrEncodings;
+    static std::unordered_map<wxString, int> encodingMap;
+    static int selection(0);
 
-    size_t iEncCnt = wxFontMapper::GetSupportedEncodingsCount();
-    for(size_t i = 0; i < iEncCnt; i++) {
-        fontEnc = wxFontMapper::GetEncoding(i);
-        if(wxFONTENCODING_SYSTEM == fontEnc) { // skip system, it is changed to UTF-8 in optionsconfig
-            continue;
+    if(astrEncodings.empty()) {
+        wxFontEncoding fontEnc;
+        size_t iEncCnt = wxFontMapper::GetSupportedEncodingsCount();
+        astrEncodings.reserve(iEncCnt);
+        for(size_t i = 0; i < iEncCnt; i++) {
+            fontEnc = wxFontMapper::GetEncoding(i);
+            if(wxFONTENCODING_SYSTEM == fontEnc) { // skip system, it is changed to UTF-8 in optionsconfig
+                continue;
+            }
+            wxString encodingName = wxFontMapper::GetEncodingName(fontEnc);
+            size_t pos = astrEncodings.Add(encodingName);
+            encodingMap.insert({ encodingName, (int)pos });
+            if(m_data.GetEncoding() == encodingName) {
+                selection = static_cast<int>(pos);
+            }
         }
-        wxString encodingName = wxFontMapper::GetEncodingName(fontEnc);
-        size_t pos = astrEncodings.Add(encodingName);
-
-        if(m_data.GetEncoding() == encodingName) { selection = static_cast<int>(pos); }
+    } else {
+        selection = encodingMap.count(m_data.GetEncoding()) ? encodingMap.find(m_data.GetEncoding())->second : 0;
     }
 
     m_choiceEncoding->Append(astrEncodings);
-    if(m_choiceEncoding->IsEmpty() == false) { m_choiceEncoding->SetSelection(selection); }
+    if(m_choiceEncoding->GetCount()) {
+        m_choiceEncoding->SetSelection(selection);
+    }
 
     // Set the file mask
     DoSetFileMask();
@@ -98,10 +113,8 @@ FindInFilesDialog::FindInFilesDialog(wxWindow* parent, FindReplaceData& data)
     // Fit the initial size and set it as the default minimum size
     GetSizer()->Fit(this);
     SetMinSize(GetSize());
-
-    // Load the last size and position, but not on GTK
-    WindowAttrManager::Load(this);
-    CentreOnParent();
+    CallAfter(&FindInFilesDialog::DoSelectAll);
+    ::clSetSmallDialogBestSizeAndPosition(this);
 }
 
 FindInFilesDialog::~FindInFilesDialog() { BuildFindReplaceData(); }
@@ -120,9 +133,12 @@ void FindInFilesDialog::DoSetFileMask()
 
     // Remove empty entries
     wxArrayString tempMaskArr;
+    tempMaskArr.reserve(fileTypes.size());
     std::for_each(fileTypes.begin(), fileTypes.end(), [&](wxString& item) {
         item.Trim().Trim(false);
-        if(!item.IsEmpty()) { tempMaskArr.Add(item); }
+        if(!item.IsEmpty()) {
+            tempMaskArr.Add(item);
+        }
     });
     fileTypes.swap(tempMaskArr);
 
@@ -159,7 +175,9 @@ SearchData FindInFilesDialog::DoGetSearchData()
 {
     SearchData data;
     wxString findStr(m_data.GetFindString());
-    if(!m_findString->GetValue().IsEmpty()) { findStr = m_findString->GetValue(); }
+    if(!m_findString->GetValue().IsEmpty()) {
+        findStr = m_findString->GetValue();
+    }
 
     data.SetFindString(findStr);
     data.SetReplaceWith(m_replaceString->GetValue());
@@ -169,7 +187,9 @@ SearchData FindInFilesDialog::DoGetSearchData()
 
     // If the 'Skip comments' is ON, remove the
     // 'colour comments' flag
-    if(flags & wxFRD_SKIP_COMMENTS) { flags &= ~wxFRD_COLOUR_COMMENTS; }
+    if(flags & wxFRD_SKIP_COMMENTS) {
+        flags &= ~wxFRD_COLOUR_COMMENTS;
+    }
 
     data.SetMatchCase((flags & wxFRD_MATCHCASE) != 0);
     data.SetMatchWholeWord((flags & wxFRD_MATCHWHOLEWORD) != 0);
@@ -225,11 +245,14 @@ SearchData FindInFilesDialog::DoGetSearchData()
             rootDirs.Add(clWorkspaceManager::Get().GetWorkspace()->GetFileName().GetPath());
 
         } else if((rootDir == wxGetTranslation(SEARCH_IN_WORKSPACE)) || (rootDir == SEARCH_IN_WORKSPACE)) {
-            if(!clWorkspaceManager::Get().IsWorkspaceOpened()) { continue; }
+            if(!clWorkspaceManager::Get().IsWorkspaceOpened()) {
+                continue;
+            }
             clWorkspaceManager::Get().GetWorkspace()->GetWorkspaceFiles(files);
 
         } else if((rootDir == wxGetTranslation(SEARCH_IN_PROJECT)) || (rootDir == SEARCH_IN_PROJECT)) {
-            if(!clWorkspaceManager::Get().IsWorkspaceOpened()) continue;
+            if(!clWorkspaceManager::Get().IsWorkspaceOpened())
+                continue;
             if(clWorkspaceManager::Get().GetWorkspace()->IsProjectSupported()) {
                 // get the active project files
                 clWorkspaceManager::Get().GetWorkspace()->GetProjectFiles("", files);
@@ -241,9 +264,11 @@ SearchData FindInFilesDialog::DoGetSearchData()
         } else if((rootDir == wxGetTranslation(SEARCH_IN_CURR_FILE_PROJECT)) ||
                   (rootDir == SEARCH_IN_CURR_FILE_PROJECT)) {
 
-            if(!clWorkspaceManager::Get().IsWorkspaceOpened()) continue;
+            if(!clWorkspaceManager::Get().IsWorkspaceOpened())
+                continue;
             IEditor* editor = clGetManager()->GetActiveEditor();
-            if(!editor) continue;
+            if(!editor)
+                continue;
 
             if(clWorkspaceManager::Get().GetWorkspace()->IsProjectSupported()) {
                 wxString projectName =
@@ -256,14 +281,18 @@ SearchData FindInFilesDialog::DoGetSearchData()
 
         } else if((rootDir == wxGetTranslation(SEARCH_IN_CURRENT_FILE)) || (rootDir == SEARCH_IN_CURRENT_FILE)) {
             clEditor* editor = clMainFrame::Get()->GetMainBook()->GetActiveEditor();
-            if(editor) { files.Add(editor->GetFileName().GetFullPath()); }
+            if(editor) {
+                files.Add(editor->GetFileName().GetFullPath());
+            }
         } else if((rootDir == wxGetTranslation(SEARCH_IN_OPEN_FILES)) || (rootDir == SEARCH_IN_OPEN_FILES)) {
             std::vector<clEditor*> editors;
             clMainFrame::Get()->GetMainBook()->GetAllEditors(editors, MainBook::kGetAll_IncludeDetached);
 
             for(size_t n = 0; n < editors.size(); ++n) {
                 clEditor* editor = dynamic_cast<clEditor*>(*(editors.begin() + n));
-                if(editor) { files.Add(editor->GetFileName().GetFullPath()); }
+                if(editor) {
+                    files.Add(editor->GetFileName().GetFullPath());
+                }
             }
         } else if(wxFileName::DirExists(searchWhere.Item(i))) {
             rootDirs.Add(searchWhere.Item(i));
@@ -334,7 +363,8 @@ void FindInFilesDialog::OnAddPath(wxCommandEvent& event)
     wxPoint menuPos(0, size.GetHeight());
     int selection = m_btnAddPath->GetPopupMenuSelectionFromUser(menu, menuPos);
 
-    if(selection == wxID_NONE) return;
+    if(selection == wxID_NONE)
+        return;
     if(selection == (firstItem + 7)) {
         // Add exclude pattern
         int lastPos = m_stcPaths->GetLastPosition();
@@ -355,7 +385,8 @@ void FindInFilesDialog::OnAddPath(wxCommandEvent& event)
 
     } else if(selection == (firstItem + 6)) {
         wxString folder = ::wxDirSelector();
-        if(folder.IsEmpty()) return;
+        if(folder.IsEmpty())
+            return;
         DoSetSearchPaths(folder);
 
     } else if(options.count(selection)) {
@@ -375,10 +406,11 @@ int FindInFilesDialog::ShowDialog()
     if(editor) {
         // if we have an open editor, and a selected text, make this text the search string
         wxString selText = editor->GetSelectedText();
-        if(!selText.IsEmpty()) { m_findString->SetValue(selText); }
+        if(!selText.IsEmpty()) {
+            m_findString->SetValue(selText);
+        }
     }
 
-    m_findString->SetSelection(-1, -1); // select all
     m_findString->CallAfter(&wxTextCtrl::SetFocus);
     return wxDialog::ShowModal();
 }
@@ -387,7 +419,9 @@ void FindInFilesDialog::DoSaveSearchPaths() { m_data.SetSearchPaths(m_stcPaths->
 
 void FindInFilesDialog::DoSaveOpenFiles()
 {
-    if(m_checkBoxSaveFilesBeforeSearching->IsChecked()) { clMainFrame::Get()->GetMainBook()->SaveAll(false, false); }
+    if(m_checkBoxSaveFilesBeforeSearching->IsChecked()) {
+        clMainFrame::Get()->GetMainBook()->SaveAll(false, false);
+    }
 }
 
 void FindInFilesDialog::OnFindWhatUI(wxUpdateUIEvent& event)
@@ -418,11 +452,16 @@ void FindInFilesDialog::OnButtonClose(wxCommandEvent& event) { EndModal(wxID_CAN
 size_t FindInFilesDialog::GetSearchFlags()
 {
     size_t flags = 0;
-    if(m_matchCase->IsChecked()) flags |= wxFRD_MATCHCASE;
-    if(m_matchWholeWord->IsChecked()) flags |= wxFRD_MATCHWHOLEWORD;
-    if(m_regualrExpression->IsChecked()) flags |= wxFRD_REGULAREXPRESSION;
-    if(m_checkBoxSaveFilesBeforeSearching->IsChecked()) flags |= wxFRD_SAVE_BEFORE_SEARCH;
-    if(m_checkBoxPipeForGrep->IsChecked()) flags |= wxFRD_ENABLE_PIPE_SUPPORT;
+    if(m_matchCase->IsChecked())
+        flags |= wxFRD_MATCHCASE;
+    if(m_matchWholeWord->IsChecked())
+        flags |= wxFRD_MATCHWHOLEWORD;
+    if(m_regualrExpression->IsChecked())
+        flags |= wxFRD_REGULAREXPRESSION;
+    if(m_checkBoxSaveFilesBeforeSearching->IsChecked())
+        flags |= wxFRD_SAVE_BEFORE_SEARCH;
+    if(m_checkBoxPipeForGrep->IsChecked())
+        flags |= wxFRD_ENABLE_PIPE_SUPPORT;
     return flags;
 }
 
@@ -438,7 +477,9 @@ void FindInFilesDialog::DoSetSearchPaths(const wxString& path)
     wxString text = m_stcPaths->GetText();
     text.Replace("\r", ""); // No \r
     text.Trim().Trim(false);
-    if(!text.IsEmpty()) { text << "\n"; }
+    if(!text.IsEmpty()) {
+        text << "\n";
+    }
     text << path;
     text.Trim().Trim(false);
     m_stcPaths->SetText(text);
@@ -455,7 +496,9 @@ void FindInFilesDialog::OnLookInKeyDown(wxKeyEvent& event) { event.Skip(); }
 
 void FindInFilesDialog::DoAddProjectFiles(const wxString& projectName, wxArrayString& files)
 {
-    if(!clCxxWorkspaceST::Get()->IsOpen()) { return; }
+    if(!clCxxWorkspaceST::Get()->IsOpen()) {
+        return;
+    }
     ProjectPtr p = clCxxWorkspaceST::Get()->GetProject(projectName);
     if(p) {
         const Project::FilesMap_t& filesMap = p->GetFiles();
@@ -487,7 +530,9 @@ void FindInFilesDialog::BuildFindReplaceData()
     value.Trim().Trim(false);
 
     wxArrayString masks = m_fileTypes->GetStrings();
-    if(masks.Index(value) == wxNOT_FOUND) { masks.Insert(value, 0); }
+    if(masks.Index(value) == wxNOT_FOUND) {
+        masks.Insert(value, 0);
+    }
 
     m_data.SetSelectedMask(value);
     m_data.SetFileMask(masks);
@@ -507,3 +552,15 @@ void FindInFilesDialog::SetFileMask(const wxString& mask)
         m_fileTypes->SetSelection(where);
     }
 }
+void FindInFilesDialog::OnFindEnter(wxCommandEvent& event)
+{
+    event.Skip();
+    OnFind(event);
+}
+
+void FindInFilesDialog::OnReplaceEnter(wxCommandEvent& event) { OnReplace(event); }
+
+void FindInFilesDialog::DoSelectAll()
+{
+    m_findString->GetTextCtrl()->SelectAll();
+}
