@@ -24,10 +24,12 @@
 //////////////////////////////////////////////////////////////////////////////
 #include "FilesModifiedDlg.h"
 #include "NotebookNavigationDlg.h"
+#include "WelcomePage.h"
 #include "clAuiMainNotebookTabArt.h"
 #include "clFileOrFolderDropTarget.h"
 #include "clImageViewer.h"
 #include "clThemeUpdater.h"
+#include "cl_defs.h"
 #include "close_all_dlg.h"
 #include "ctags_manager.h"
 #include "editor_config.h"
@@ -64,7 +66,10 @@ MainBook::MainBook(wxWindow* parent)
     , m_welcomePage(NULL)
     , m_findBar(NULL)
 {
+#if !CL_USE_NATIVEBOOK
     clThemeUpdater::Get().RegisterWindow(this);
+#endif
+
     CreateGuiControls();
     ConnectEvents();
 }
@@ -73,20 +78,35 @@ void MainBook::CreateGuiControls()
 {
     wxBoxSizer* sz = new wxBoxSizer(wxVERTICAL);
     SetSizer(sz);
+#if CL_USE_NATIVEBOOK
+    long style = kNotebook_AllowDnD |                  // Allow tabs to move
+                 kNotebook_MouseMiddleClickClosesTab | // Handle mouse middle button when clicked on a tab
+                 kNotebook_MouseMiddleClickFireEvent | // instead of closing the tab, fire an event
+                 kNotebook_ShowFileListButton |        // show drop down list of all open tabs
+                 kNotebook_EnableNavigationEvent |     // Notify when user hit Ctrl-TAB or Ctrl-PGDN/UP
+                 kNotebook_NewButton;
+#else
     long style = kNotebook_AllowDnD |                  // Allow tabs to move
                  kNotebook_MouseMiddleClickClosesTab | // Handle mouse middle button when clicked on a tab
                  kNotebook_MouseMiddleClickFireEvent | // instead of closing the tab, fire an event
                  kNotebook_ShowFileListButton |        // show drop down list of all open tabs
                  kNotebook_EnableNavigationEvent |     // Notify when user hit Ctrl-TAB or Ctrl-PGDN/UP
                  kNotebook_UnderlineActiveTab |        // Mark active tab with dedicated coloured line
-                 kNotebook_DynamicColours;             // The tabs colour adjust to the editor's theme
+                 kNotebook_DynamicColours |            // The tabs colour adjust to the editor's theme
+                 kNotebook_NewButton;
+    style |= kNotebook_AllowForeignDnD;
+#endif
+
     if(EditorConfigST::Get()->GetOptions()->IsTabHasXButton()) {
         style |= (kNotebook_CloseButtonOnActiveTabFireEvent | kNotebook_CloseButtonOnActiveTab);
     }
     if(EditorConfigST::Get()->GetOptions()->IsMouseScrollSwitchTabs()) {
         style |= kNotebook_MouseScrollSwitchTabs;
     }
-    style |= kNotebook_AllowForeignDnD;
+
+    if(clConfig::Get().Read("HideTabBar", false)) {
+        style |= kNotebook_HideTabBar;
+    }
 
     // load the notebook style from the configuration settings
     m_book = new Notebook(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, style);
@@ -101,7 +121,7 @@ void MainBook::ConnectEvents()
     m_book->Bind(wxEVT_BOOK_PAGE_CHANGED, &MainBook::OnPageChanged, this);
     m_book->Bind(wxEVT_BOOK_PAGE_CHANGING, &MainBook::OnPageChanging, this);
     m_book->Bind(wxEVT_BOOK_PAGE_CLOSE_BUTTON, &MainBook::OnClosePage, this);
-    m_book->Bind(wxEVT_BOOK_TABAREA_DCLICKED, &MainBook::OnMouseDClick, this);
+    m_book->Bind(wxEVT_BOOK_NEW_PAGE, &MainBook::OnMouseDClick, this);
     m_book->Bind(wxEVT_BOOK_TAB_DCLICKED, &MainBook::OnTabDClicked, this);
     m_book->Bind(wxEVT_BOOK_TAB_CONTEXT_MENU, &MainBook::OnTabLabelContextMenu, this);
 
@@ -136,7 +156,7 @@ MainBook::~MainBook()
     m_book->Unbind(wxEVT_BOOK_PAGE_CHANGED, &MainBook::OnPageChanged, this);
     m_book->Unbind(wxEVT_BOOK_PAGE_CHANGING, &MainBook::OnPageChanging, this);
     m_book->Unbind(wxEVT_BOOK_PAGE_CLOSE_BUTTON, &MainBook::OnClosePage, this);
-    m_book->Unbind(wxEVT_BOOK_TABAREA_DCLICKED, &MainBook::OnMouseDClick, this);
+    m_book->Unbind(wxEVT_BOOK_NEW_PAGE, &MainBook::OnMouseDClick, this);
     m_book->Unbind(wxEVT_BOOK_TAB_DCLICKED, &MainBook::OnTabDClicked, this);
     m_book->Unbind(wxEVT_BOOK_TAB_CONTEXT_MENU, &MainBook::OnTabLabelContextMenu, this);
 
@@ -177,7 +197,6 @@ void MainBook::OnMouseDClick(wxBookCtrlEvent& e)
 void MainBook::OnPageClosing(wxBookCtrlEvent& e)
 {
     e.Skip();
-
     clEditor* editor = dynamic_cast<clEditor*>(m_book->GetPage(e.GetSelection()));
     if(editor) {
         if(AskUserToSave(editor)) {
@@ -303,7 +322,7 @@ void MainBook::UpdateNavBar(clEditor* editor)
 {
     TagEntryPtr tag = NULL;
     if(m_navBar && m_navBar->IsShown()) {
-        if(editor && !editor->GetProject().IsEmpty()) {
+        if(editor) {
             TagEntryPtrVector_t tags;
             if(TagsManagerST::Get()->GetFileCache()->Find(editor->GetFileName(), tags,
                                                           clCxxFileCacheSymbols::kFunctions)) {
@@ -531,16 +550,19 @@ clEditor* MainBook::NewEditor()
     fileNameStr << ++fileCounter;
     wxFileName fileName(fileNameStr);
 
+#if !CL_USE_NATIVEBOOK
     // A Nice trick: hide the notebook, open the editor
     // and then show it
     bool hidden(false);
     if(m_book->GetPageCount() == 0)
         hidden = GetSizer()->Hide(m_book);
+#endif
 
     clEditor* editor = new clEditor(m_book);
     editor->SetFileName(fileName);
     AddPage(editor, fileName.GetFullName(), fileName.GetFullPath(), wxNullBitmap, true);
 
+#if !CL_USE_NATIVEBOOK
     if(m_book->GetSizer()) {
         m_book->GetSizer()->Layout();
     }
@@ -548,6 +570,7 @@ clEditor* MainBook::NewEditor()
     // SHow the notebook
     if(hidden)
         GetSizer()->Show(m_book);
+#endif
 
     editor->SetActive();
     return editor;
@@ -621,13 +644,13 @@ clEditor* MainBook::OpenFile(const wxString& file_name, const wxString& projectN
         return NULL;
 
     } else {
-
+#if !CL_USE_NATIVEBOOK
         // A Nice trick: hide the notebook, open the editor
         // and then show it
         bool hidden(false);
         if(m_book->GetPageCount() == 0)
             hidden = GetSizer()->Hide(m_book);
-
+#endif
         editor = new clEditor(m_book);
         editor->SetEditorBitmap(bmp);
         editor->Create(projName, fileName);
@@ -647,9 +670,11 @@ clEditor* MainBook::OpenFile(const wxString& file_name, const wxString& projectN
         // mark the editor as read only if needed
         MarkEditorReadOnly(editor);
 
+#if !CL_USE_NATIVEBOOK
         // Show the notebook
         if(hidden)
             GetSizer()->Show(m_book);
+#endif
 
         if(position == wxNOT_FOUND && lineno == wxNOT_FOUND && editor->GetContext()->GetName() == wxT("C++")) {
             // try to find something interesting in the file to put the caret at
@@ -726,7 +751,7 @@ bool MainBook::SelectPage(wxWindow* win)
 {
     int index = m_book->GetPageIndex(win);
     if(index != wxNOT_FOUND && m_book->GetSelection() != index) {
-#if USE_AUI_NOTEBOOK
+#if !CL_USE_NATIVEBOOK
         m_book->ChangeSelection(index);
 #else
         m_book->SetSelection(index);
@@ -892,11 +917,9 @@ void MainBook::ReloadExternallyModified(bool prompt)
     }
     if(filesToRetag.size() > 1) {
         TagsManagerST::Get()->RetagFiles(filesToRetag, TagsManager::Retag_Quick);
-        SendCmdEvent(wxEVT_FILE_RETAGGED, (void*)&filesToRetag);
 
     } else if(filesToRetag.size() == 1) {
         ManagerST::Get()->RetagFile(filesToRetag.at(0).GetFullPath());
-        SendCmdEvent(wxEVT_FILE_RETAGGED, (void*)&filesToRetag);
     }
 }
 
@@ -1029,11 +1052,34 @@ void MainBook::SetPageTitle(wxWindow* page, const wxString& name)
 void MainBook::ApplySettingsChanges()
 {
     DoUpdateEditorsThemes();
+    clEditor::Vec_t allEditors;
+    GetAllEditors(allEditors, MainBook::kGetAll_IncludeDetached);
+    for(auto editor : allEditors) {
+        editor->UpdateOptions();
+    }
 
     clMainFrame::Get()->UpdateAUI();
     clMainFrame::Get()->ShowOrHideCaptions();
 }
 
+void MainBook::ApplyTabLabelChanges()
+{
+    // We only want to do this if there *is* a change, and it's hard to be sure
+    // by looking.  So store any previous state in:
+    static int previousShowParentPath = -1;
+
+    if(previousShowParentPath < 0 ||
+       EditorConfigST::Get()->GetOptions()->IsTabShowPath() != (bool)previousShowParentPath) {
+        previousShowParentPath = EditorConfigST::Get()->GetOptions()->IsTabShowPath();
+
+        std::vector<clEditor*> editors;
+        GetAllEditors(editors, MainBook::kGetAll_IncludeDetached);
+        for(size_t i = 0; i < editors.size(); i++) {
+            SetPageTitle(editors[i], editors[i]->GetFileName(), editors[i]->IsModified());
+        }
+    }
+}
+
 void MainBook::UnHighlightAll()
 {
     std::vector<clEditor*> editors;
@@ -1172,22 +1218,9 @@ void MainBook::OnPageChanged(wxBookCtrlEvent& e)
 
 void MainBook::DoUpdateNotebookTheme()
 {
+#if !CL_USE_NATIVEBOOK
     size_t initialStyle = m_book->GetStyle();
     size_t style = m_book->GetStyle();
-
-    // Update colours
-    IEditor* editor = GetActiveEditor();
-    if(editor) {
-        wxColour bgColour = editor->GetCtrl()->StyleGetBackground(0);
-        if(DrawingUtils::IsDark(bgColour) && !(m_book->GetStyle() & kNotebook_DarkTabs)) {
-            style &= ~kNotebook_LightTabs;
-            style |= kNotebook_DarkTabs;
-        } else if(!DrawingUtils::IsDark(bgColour) && !(m_book->GetStyle() & kNotebook_LightTabs)) {
-            style &= ~kNotebook_DarkTabs;
-            style |= kNotebook_LightTabs;
-        }
-    }
-
     // Close button
     if(!EditorConfigST::Get()->GetOptions()->IsTabHasXButton()) {
         style &= ~(kNotebook_CloseButtonOnActiveTab | kNotebook_CloseButtonOnActiveTabFireEvent);
@@ -1197,6 +1230,7 @@ void MainBook::DoUpdateNotebookTheme()
     if(initialStyle != style) {
         m_book->SetStyle(style);
     }
+#endif
 }
 
 wxWindow* MainBook::GetCurrentPage() { return m_book->GetCurrentPage(); }
@@ -1627,7 +1661,21 @@ void MainBook::OnNavigationBarMenuSelectionMade(clCommandEvent& e)
     editor->FindAndSelect(tag->GetPattern(), tag->GetName(), editor->PosFromLine(tag->GetLine() - 1), nullptr);
 }
 
-void MainBook::OnSettingsChanged(wxCommandEvent& e) { e.Skip(); }
+void MainBook::OnSettingsChanged(wxCommandEvent& e)
+{
+    e.Skip();
+    ApplyTabLabelChanges();
+
+    // do we need to hide/show the tab bar?
+    bool hideTabBar = clConfig::Get().Read("HideTabBar", false);
+    size_t style = m_book->GetStyle();
+    if(hideTabBar) {
+        style |= kNotebook_HideTabBar;
+    } else {
+        style &= ~kNotebook_HideTabBar;
+    }
+    m_book->SetStyle(style);
+}
 
 clEditor* MainBook::OpenFile(const BrowseRecord& rec)
 {
@@ -1667,60 +1715,31 @@ void MainBook::DoShowTabLabelContextMenu()
 
 void MainBook::RegisterWelcomePage(wxWindow* welcomePage)
 {
-    wxWindowUpdateLocker locker(this);
-    // Hide the current one, if any
-    DoShowWindow(m_welcomePage, false);
-    if(m_welcomePage) {
-        m_welcomePage->Destroy();
-    }
-    m_welcomePage = welcomePage;
-
-    if(!m_welcomePage)
-        return; // Nothing more to do here
-    m_welcomePage->Reparent(this);
-
-    DoShowWindow(m_welcomePage, false);
-    DoShowWindow(m_book, true);
-    if(m_book->GetSizer()) {
-        m_book->GetSizer()->Layout();
-    }
+    wxUnusedVar(welcomePage);
+    m_book->AddPage(new WelcomePage(m_book), wxT("Welcome!"), true);
 }
 
 void MainBook::DoShowWindow(wxWindow* win, bool show)
 {
-    if(!win)
-        return;
-    if(show) {
-        if(GetSizer()->GetItem(win))
-            return; // already visible
-        GetSizer()->Add(win, 1, wxEXPAND);
-        win->Show();
-    } else {
-        if(!GetSizer()->GetItem(win))
-            return;
-        GetSizer()->Detach(win);
-        win->Hide();
-    }
+    wxUnusedVar(win);
+    wxUnusedVar(show);
 }
 
 void MainBook::ShowWelcomePage(bool show)
 {
-    if(!m_welcomePage) {
-        return;
-    }
-    if(show && m_welcomePage->IsShown()) {
-        return;
-    }
-    if(!show && !m_welcomePage->IsShown()) {
-        return;
-    }
+    int where = m_book->GetPageIndex(wxT("Welcome!"));
+    if(show) {
+        GetSizer()->Show(m_book);
+        if(where == wxNOT_FOUND) {
+            m_book->AddPage(new WelcomePage(m_book), wxT("Welcome!"), true);
+        } else {
+            m_book->SetSelection(where);
+        }
 
-    wxWindowUpdateLocker locker(this);
-    DoShowWindow(m_welcomePage, show);
-    DoShowWindow(m_book, !show);
-    GetSizer()->Layout();
-    if(m_book->GetSizer()) {
-        m_book->GetSizer()->Layout();
+    } else {
+        if(where != wxNOT_FOUND) {
+            m_book->DeletePage(where, false);
+        }
     }
 }
 
@@ -1790,7 +1809,7 @@ void MainBook::SetPageTitle(wxWindow* page, const wxFileName& filename, bool mod
 wxString MainBook::CreateLabel(const wxFileName& fn, bool modified) const
 {
     wxString label = fn.GetFullName();
-    if(fn.GetDirCount()) {
+    if(fn.GetDirCount() && EditorConfigST::Get()->GetOptions()->IsTabShowPath()) {
         label.Prepend(fn.GetDirs().Last() + wxFileName::GetPathSeparator());
     }
     if(modified) {
