@@ -22,7 +22,7 @@
 //
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
-#include "add_option_dialog.h"
+#include "AddOptionsDialog.h"
 #include "addoptioncheckdlg.h"
 #include "build_settings_config.h"
 #include "configuration_manager_dlg.h"
@@ -79,16 +79,9 @@ ProjectSettingsDlg::ProjectSettingsDlg(wxWindow* parent, WorkspaceTab* workspace
     LoadValues(m_configName);
 
     m_treebook->SetFocus();
-    GetSizer()->Fit(this);
 
-    wxSize sz = GetSize();
     CentreOnParent();
     SetName("ProjectSettingsDlg");
-    WindowAttrManager::Load(this);
-
-    // Make sure that all the controls are visible
-    wxSize newSize = GetSize();
-    if(newSize.x <= sz.x && newSize.y <= sz.y) { GetSizer()->Fit(this); }
 
     EventNotifier::Get()->Connect(wxEVT_PROJECT_TREEITEM_CLICKED,
                                   wxCommandEventHandler(ProjectSettingsDlg::OnProjectSelected), NULL, this);
@@ -97,13 +90,8 @@ ProjectSettingsDlg::ProjectSettingsDlg(wxWindow* parent, WorkspaceTab* workspace
 
     // No effects plz
     m_infobar->SetShowHideEffects(wxSHOW_EFFECT_NONE, wxSHOW_EFFECT_NONE);
-
     ShowHideDisabledMessage();
-    if(!wxPersistenceManager::Get().Find(m_treebook)) {
-        wxPersistenceManager::Get().RegisterAndRestore(m_treebook);
-    } else {
-        wxPersistenceManager::Get().Restore(m_treebook);
-    }
+    ::clSetDialogBestSizeAndPosition(this);
 }
 
 void ProjectSettingsDlg::DoClearDialog()
@@ -175,15 +163,20 @@ void ProjectSettingsDlg::OnButtonApply(wxCommandEvent& event)
 void ProjectSettingsDlg::SaveValues()
 {
     ProjectSettingsPtr projSettingsPtr = ManagerST::Get()->GetProjectSettings(m_projectName);
+    wxCHECK_RET(projSettingsPtr, "Project settings not found");
     BuildConfigPtr buildConf = projSettingsPtr->GetBuildConfiguration(m_configName);
-    if(!buildConf) { return; }
+    if(!buildConf) {
+        return;
+    }
 
     size_t pageCount = m_treebook->GetPageCount();
     for(size_t i = 0; i < pageCount; i++) {
         wxWindow* page = m_treebook->GetPage(i);
         if(!page) continue;
         IProjectSettingsPage* p = dynamic_cast<IProjectSettingsPage*>(page);
-        if(p) { p->Save(buildConf, projSettingsPtr); }
+        if(p) {
+            p->Save(buildConf, projSettingsPtr);
+        }
     }
 
     // save settings
@@ -203,8 +196,11 @@ void ProjectSettingsDlg::LoadValues(const wxString& configName)
     PluginManager::Get()->HookProjectSettingsTab(m_treebook, m_projectName, configName);
     BuildConfigPtr buildConf;
     ProjectSettingsPtr projSettingsPtr = ManagerST::Get()->GetProjectSettings(m_projectName);
+    wxCHECK_RET(projSettingsPtr, "Project settings not found");
     buildConf = projSettingsPtr->GetBuildConfiguration(configName);
-    if(!buildConf) { return; }
+    if(!buildConf) {
+        return;
+    }
 
     if(buildConf->GetProjectType().IsEmpty()) {
         // no project type is defined by the
@@ -225,7 +221,9 @@ void ProjectSettingsDlg::LoadValues(const wxString& configName)
         }
     }
 
-    if(sel != wxNOT_FOUND) { m_treebook->SetSelection(sel); }
+    if(sel != wxNOT_FOUND) {
+        m_treebook->SetSelection(sel);
+    }
     m_isDirty = false;
 }
 
@@ -237,7 +235,9 @@ void ProjectSettingsDlg::ClearValues()
         if(!page) continue;
 
         IProjectSettingsPage* p = dynamic_cast<IProjectSettingsPage*>(page);
-        if(p) { p->Clear(); }
+        if(p) {
+            p->Clear();
+        }
     }
 }
 
@@ -255,7 +255,10 @@ void ProjectSettingsDlg::OnButtonHelp(wxCommandEvent& e)
 #endif
 }
 
-void ProjectSettingsDlg::OnButtonApplyUI(wxUpdateUIEvent& event) { event.Enable(GetIsDirty()); }
+void ProjectSettingsDlg::OnButtonApplyUI(wxUpdateUIEvent& event)
+{
+    event.Enable(GetIsDirty());
+}
 
 void ProjectSettingsDlg::OnConfigurationChanged(wxCommandEvent& event)
 {
@@ -319,6 +322,7 @@ void ProjectSettingsDlg::DoGetAllBuildConfigs()
     m_choiceConfig->Clear();
     wxArrayString configs;
     ProjectSettingsPtr projSettingsPtr = ManagerST::Get()->GetProjectSettings(m_projectName);
+    wxCHECK_RET(projSettingsPtr, "Project settings not found");
     ProjectSettingsCookie cookie;
     BuildConfigPtr conf = projSettingsPtr->GetFirstBuildConfiguration(cookie);
     while(conf) {
@@ -404,7 +408,7 @@ void ProjectSettingsDlg::OnPageChanged(wxTreebookEvent& event)
 ///////////////////////////////////////////////////////////////////////////
 
 GlobalSettingsPanel::GlobalSettingsPanel(wxWindow* parent, const wxString& projectName, ProjectSettingsDlg* dlg,
-                                         PSGeneralPage* gp)
+        PSGeneralPage* gp)
     : GlobalSettingsBasePanel(parent)
     , m_projectName(projectName)
     , m_dlg(dlg)
@@ -419,13 +423,16 @@ void GlobalSettingsPanel::Clear()
 {
     wxPropertyGridIterator iter = m_pgMgr->GetGrid()->GetIterator();
     for(; !iter.AtEnd(); ++iter) {
-        if(iter.GetProperty() && !iter.GetProperty()->IsCategory()) { iter.GetProperty()->SetValueToUnspecified(); }
+        if(iter.GetProperty() && !iter.GetProperty()->IsCategory()) {
+            iter.GetProperty()->SetValueToUnspecified();
+        }
     }
 }
 
 void GlobalSettingsPanel::Load(BuildConfigPtr buildConf)
 {
     ProjectSettingsPtr projSettingsPtr = ManagerST::Get()->GetProjectSettings(m_projectName);
+    wxCHECK_RET(projSettingsPtr, "Project settings not found");
     BuildConfigCommonPtr globalSettings = projSettingsPtr->GetGlobalSettings();
     if(!globalSettings) {
         Clear();
@@ -449,7 +456,9 @@ void GlobalSettingsPanel::Save(BuildConfigPtr buildConf, ProjectSettingsPtr proj
     wxUnusedVar(projSettingsPtr);
 
     BuildConfigCommonPtr globalSettings = projSettingsPtr->GetGlobalSettings();
-    if(!globalSettings) { return; }
+    if(!globalSettings) {
+        return;
+    }
 
     globalSettings->SetCompileOptions(m_pgPropCppCmpOpts->GetValueAsString());
     globalSettings->SetCCompileOptions(m_pgPropCCmpOpts->GetValueAsString());
@@ -478,18 +487,27 @@ void GlobalSettingsPanel::OnCustomEditorClicked(wxCommandEvent& event)
 
     if(prop == m_pgPropCCmpOpts || prop == m_pgPropCppCmpOpts) {
         wxString v = prop->GetValueAsString();
-        if(PopupAddOptionCheckDlg(v, _("Compiler Options"), cmp->GetCompilerOptions())) { prop->SetValueFromString(v); }
+        if(PopupAddOptionCheckDlg(v, _("Compiler Options"), cmp->GetCompilerOptions())) {
+            prop->SetValueFromString(v);
+        }
     } else if(prop == m_pgPropIncludePaths || prop == m_pgPropPreProcessors || prop == m_pgPropLibPath ||
               prop == m_pgPropLIbs || prop == m_pgPropResCmpOptions || prop == m_pgPropResCmpSearchPath) {
         wxString v = prop->GetValueAsString();
-        if(PopupAddOptionDlg(v)) { prop->SetValueFromString(v); }
+        if(PopupAddOptionDlg(v)) {
+            prop->SetValueFromString(v);
+        }
     } else if(prop == m_pgPropOptions) {
         wxString v = prop->GetValueAsString();
-        if(PopupAddOptionCheckDlg(v, _("Linker Options"), cmp->GetLinkerOptions())) { prop->SetValueFromString(v); }
+        if(PopupAddOptionCheckDlg(v, _("Linker Options"), cmp->GetLinkerOptions())) {
+            prop->SetValueFromString(v);
+        }
     }
 }
 
-void GlobalSettingsPanel::OnValueChanged(wxPropertyGridEvent& event) { m_dlg->SetIsDirty(true); }
+void GlobalSettingsPanel::OnValueChanged(wxPropertyGridEvent& event)
+{
+    m_dlg->SetIsDirty(true);
+}
 
 //////////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////////
@@ -498,7 +516,7 @@ void GlobalSettingsPanel::OnValueChanged(wxPropertyGridEvent& event) { m_dlg->Se
 
 bool IProjectSettingsPage::PopupAddOptionDlg(wxTextCtrl* ctrl)
 {
-    AddOptionDlg dlg(NULL, ctrl->GetValue());
+    AddOptionsDialog dlg(EventNotifier::Get()->TopFrame(), ctrl->GetValue());
     if(dlg.ShowModal() == wxID_OK) {
         ctrl->SetValue(dlg.GetValue());
         return true;
@@ -508,7 +526,7 @@ bool IProjectSettingsPage::PopupAddOptionDlg(wxTextCtrl* ctrl)
 
 bool IProjectSettingsPage::PopupAddOptionDlg(wxString& value)
 {
-    AddOptionDlg dlg(NULL, value);
+    AddOptionsDialog dlg(EventNotifier::Get()->TopFrame(), value);
     if(dlg.ShowModal() == wxID_OK) {
         value.Clear();
         value << dlg.GetValue();
@@ -536,7 +554,7 @@ bool IProjectSettingsPage::SelectChoiceWithGlobalSettings(wxChoice* c, const wxS
 }
 
 bool IProjectSettingsPage::PopupAddOptionCheckDlg(wxTextCtrl* ctrl, const wxString& title,
-                                                  const Compiler::CmpCmdLineOptions& options)
+        const Compiler::CmpCmdLineOptions& options)
 {
     AddOptionCheckDlg dlg(NULL, title, options, ctrl->GetValue());
     if(dlg.ShowModal() == wxID_OK) {
@@ -547,7 +565,7 @@ bool IProjectSettingsPage::PopupAddOptionCheckDlg(wxTextCtrl* ctrl, const wxStri
 }
 
 bool IProjectSettingsPage::PopupAddOptionCheckDlg(wxString& v, const wxString& title,
-                                                  const Compiler::CmpCmdLineOptions& options)
+        const Compiler::CmpCmdLineOptions& options)
 {
     AddOptionCheckDlg dlg(NULL, title, options, v);
     if(dlg.ShowModal() == wxID_OK) {
