@@ -1,6 +1,7 @@
 #include "CompileCommandsGenerator.h"
 #include "JSON.h"
 #include "NewFileSystemWorkspaceDialog.h"
+#include "StringUtils.h"
 #include "asyncprocess.h"
 #include "build_settings_config.h"
 #include "clConsoleBase.h"
@@ -60,7 +61,7 @@ clFileSystemWorkspace::clFileSystemWorkspace(bool dummy)
         EventNotifier::Get()->Bind(wxEVT_CMD_RETAG_WORKSPACE, &clFileSystemWorkspace::OnParseWorkspace, this);
         EventNotifier::Get()->Bind(wxEVT_CMD_RETAG_WORKSPACE_FULL, &clFileSystemWorkspace::OnParseWorkspace, this);
         EventNotifier::Get()->Bind(wxEVT_SAVE_SESSION_NEEDED, &clFileSystemWorkspace::OnSaveSession, this);
-        Bind(wxEVT_PARSE_THREAD_SCAN_INCLUDES_DONE, &clFileSystemWorkspace::OnParseThreadScanIncludeCompleted, this);
+        Bind(wxPARSE_THREAD_SCAN_INCLUDES_DONE, &clFileSystemWorkspace::OnParseThreadScanIncludeCompleted, this);
         EventNotifier::Get()->Bind(wxEVT_SOURCE_CONTROL_PULLED, &clFileSystemWorkspace::OnSourceControlPulled, this);
 
         // Build events
@@ -103,7 +104,7 @@ clFileSystemWorkspace::~clFileSystemWorkspace()
         // parsing event
         EventNotifier::Get()->Unbind(wxEVT_CMD_RETAG_WORKSPACE, &clFileSystemWorkspace::OnParseWorkspace, this);
         EventNotifier::Get()->Unbind(wxEVT_CMD_RETAG_WORKSPACE_FULL, &clFileSystemWorkspace::OnParseWorkspace, this);
-        Unbind(wxEVT_PARSE_THREAD_SCAN_INCLUDES_DONE, &clFileSystemWorkspace::OnParseThreadScanIncludeCompleted, this);
+        Unbind(wxPARSE_THREAD_SCAN_INCLUDES_DONE, &clFileSystemWorkspace::OnParseThreadScanIncludeCompleted, this);
         EventNotifier::Get()->Unbind(wxEVT_SOURCE_CONTROL_PULLED, &clFileSystemWorkspace::OnSourceControlPulled, this);
 
         // Build events
@@ -189,11 +190,26 @@ void clFileSystemWorkspace::CacheFiles(bool force)
             wxStringSet_t excludeFolders = { ".git", ".svn", ".codelite" };
             fs.Scan(rootFolder, files, GetFilesMask(), "", excludeFolders);
 
+            wxString excludePaths = GetExcludeFolders();
+            wxArrayString paths = StringUtils::BuildArgv(excludePaths);
+            if(!paths.IsEmpty()) {
+                for(wxString& excludePath : paths) {
+                    excludePath.Trim().Trim(false);
+                    if(excludePath.EndsWith("/") || excludePath.EndsWith("\\")) {
+                        excludePath.RemoveLast();
+                    }
+                    if(excludePath.IsEmpty()) {
+                        continue;
+                    }
+                    excludeFolders.insert(excludePath);
+                }
+            }
+            fs.Scan(rootFolder, files, GetFilesMask(), "", excludeFolders);
             clFileSystemEvent event(wxEVT_FS_SCAN_COMPLETED);
             wxArrayString arrfiles;
             arrfiles.Alloc(files.size());
-            for(const wxString& f : files) {
-                arrfiles.Add(f);
+            for(const wxFileName& f : files) {
+                arrfiles.Add(f.GetFullPath());
             }
             event.SetPaths(arrfiles);
             EventNotifier::Get()->QueueEvent(event.Clone());
@@ -259,6 +275,7 @@ void clFileSystemWorkspace::Save(bool parse)
     }
     m_settings.Save(m_filename);
 
+    // Fire 'saved' event
     clCommandEvent eventFileSave(wxEVT_FILE_SAVED);
     eventFileSave.SetFileName(m_filename.GetFullPath());
     eventFileSave.SetString(m_filename.GetFullPath());
@@ -282,12 +299,24 @@ void clFileSystemWorkspace::RestoreSession()
 
 void clFileSystemWorkspace::DoOpen()
 {
+    // set the working directory to the workspace view
+    ::wxSetWorkingDirectory(GetFileName().GetPath());
+
     // Create the symbols db file
     wxFileName fnFolder(GetFileName());
     fnFolder.SetExt("db");
     fnFolder.AppendDir(".codelite");
     fnFolder.Mkdir(wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
 
+    // Load the backticks cache file, this needs to be done early as we can
+    // since it is used
+    if(m_backtickCache) {
+        m_backtickCache.reset(nullptr);
+    }
+
+    // load the new cache
+    m_backtickCache.reset(new clBacktickCache(GetFileName().GetPath()));
+
     // Init the view
     GetView()->Clear();
 
@@ -349,23 +378,27 @@ void clFileSystemWorkspace::DoClose()
     ParseThreadST::Get()->SetSearchPaths(paths, {});
     clDEBUG() << "Parser paths are now set to:" << paths;
 
-    // Notify workspace closed event
-    wxCommandEvent event(wxEVT_WORKSPACE_CLOSED);
-    EventNotifier::Get()->ProcessEvent(event);
-
     // Notify codelite to close the currently opened workspace
     wxCommandEvent eventClose(wxEVT_MENU, wxID_CLOSE_ALL);
     eventClose.SetEventObject(EventNotifier::Get()->TopFrame());
     EventNotifier::Get()->TopFrame()->GetEventHandler()->ProcessEvent(eventClose);
 
+    // Notify workspace closed event
+    wxCommandEvent event(wxEVT_WORKSPACE_CLOSED);
+    EventNotifier::Get()->ProcessEvent(event);
+
     // Free the database
     TagsManagerST::Get()->CloseDatabase();
 
     m_isLoaded = false;
     m_showWelcomePage = true;
 
-    wxDELETE(m_buildProcess);
+    if(m_backtickCache) {
+        m_backtickCache->Save();
+        m_backtickCache.reset(nullptr);
+    }
 
+    wxDELETE(m_buildProcess);
     GetView()->UpdateConfigs({}, wxString());
 }
 
@@ -434,45 +467,50 @@ void clFileSystemWorkspace::Parse(bool fullParse)
     UpdateParserPaths();
 
     // Create a parsing request
-    ParseRequest* parsingRequest = new ParseRequest(EventNotifier::Get()->TopFrame());
-    parsingRequest->_workspaceFiles.reserve(m_files.GetSize());
+    ParseRequest* parsingRequest = new ParseRequest(this);
+
     // use a deep copy to endure thread safety
+    wxArrayString files;
+    files.Alloc(m_files.GetSize());
     for(const wxFileName& fn : m_files) {
         // filter any non valid coding file
-        parsingRequest->_workspaceFiles.push_back(fn.GetFullPath().ToAscii().data());
+        files.push_back(fn.GetFullPath());
     }
-
-    parsingRequest->setType(ParseRequest::PR_PARSEINCLUDES);
-    parsingRequest->setDbFile(TagsManagerST::Get()->GetDatabase()->GetDatabaseFileName().GetFullPath().c_str());
-    parsingRequest->_evtHandler = this;
-    parsingRequest->_quickRetag = !fullParse;
+    parsingRequest->SetWorkspaceFiles(files);
+    parsingRequest->SetType(ParseRequest::PR_PARSEINCLUDES);
+    parsingRequest->SetDbfile(TagsManagerST::Get()->GetDatabase()->GetDatabaseFileName().GetFullPath());
+    parsingRequest->SetQuickRetag(!fullParse);
     ParseThreadST::Get()->Add(parsingRequest);
     clGetManager()->SetStatusMessage(_("Scanning for files to parse..."));
 }
 
-void clFileSystemWorkspace::OnParseThreadScanIncludeCompleted(wxCommandEvent& event)
+void clFileSystemWorkspace::OnParseThreadScanIncludeCompleted(clParseThreadEvent& event)
 {
     clGetManager()->SetStatusMessage(_("Parsing..."));
 
     wxBusyCursor busyCursor;
-    std::set<wxString>* fileSet = (std::set<wxString>*)event.GetClientData();
+    const wxArrayString& files = event.GetFiles();
+
+    wxStringSet_t S;
+    S.reserve(files.size() + m_files.GetSize());
+
+    for(const wxString& file : files) {
+        S.insert(file);
+    }
 
     // add to this set the workspace files to create a unique list of
     // files
     for(const wxFileName& fn : m_files) {
-        fileSet->insert(fn.GetFullPath());
+        S.insert(fn.GetFullPath());
     }
 
     // recreate the list in the form of vector (the API requirs vector)
-    std::vector<wxFileName> vFiles;
-    vFiles.reserve(fileSet->size());
-    vFiles.insert(vFiles.end(), fileSet->begin(), fileSet->end());
+    std::vector<wxString> vFiles;
+    vFiles.reserve(S.size());
+    vFiles.insert(vFiles.end(), S.begin(), S.end());
 
-    // -----------------------------------------------
-    // tag them
-    // -----------------------------------------------
-    TagsManagerST::Get()->RetagFiles(vFiles, event.GetInt() ? TagsManager::Retag_Quick : TagsManager::Retag_Full);
-    wxDELETE(fileSet);
+    // tag'em
+    TagsManagerST::Get()->RetagFiles(vFiles, event.IsQuickParse() ? TagsManager::Retag_Quick : TagsManager::Retag_Full);
 }
 
 void clFileSystemWorkspace::UpdateParserPaths()
@@ -486,26 +524,13 @@ void clFileSystemWorkspace::UpdateParserPaths()
     clEnvironment env(&envlist);
 
     // Update the parser paths
-    wxString compile_flags_txt;
-    wxArrayString uniquePaths = GetConfig()->GetSearchPaths(GetFileName(), compile_flags_txt);
+    wxArrayString uniquePaths = GetConfig()->GetSearchPaths(GetFileName());
 
     // Expand any macros
     for(wxString& path : uniquePaths) {
         path = MacroManager::Instance()->Expand(path, nullptr, "", "");
     }
 
-    if(!compile_flags_txt.empty()) {
-        compile_flags_txt = MacroManager::Instance()->Expand(compile_flags_txt, nullptr, "", "");
-        wxFileName fnCompileFlags(GetFileName());
-        fnCompileFlags.SetFullName("compile_flags.txt");
-        FileUtils::WriteFileContent(fnCompileFlags, compile_flags_txt, wxConvUTF8);
-
-        // Fire JSON Generated event
-        clCommandEvent eventCompileCommandsGenerated(wxEVT_COMPILE_COMMANDS_JSON_GENERATED);
-        EventNotifier::Get()->QueueEvent(eventCompileCommandsGenerated.Clone());
-        clDEBUG() << "File:" << fnCompileFlags << "generated";
-    }
-
     ParseThreadST::Get()->SetSearchPaths(uniquePaths, {});
     clDEBUG() << "[" << GetConfig()->GetName() << "]"
               << "Parser paths are now set to:" << uniquePaths;
@@ -548,7 +573,7 @@ void clFileSystemWorkspace::OnBuildProcessTerminated(clProcessEvent& event)
 
         clCommandEvent e(wxEVT_SHELL_COMMAND_PROCESS_ENDED);
         EventNotifier::Get()->AddPendingEvent(e);
-        
+
         // Notify about build process started
         clBuildEvent eventStopped(wxEVT_BUILD_ENDED);
         EventNotifier::Get()->AddPendingEvent(eventStopped);
@@ -596,12 +621,13 @@ void clFileSystemWorkspace::OnExecute(clExecuteEvent& event)
         return;
     }
 
-    wxString exe, args;
-    GetExecutable(exe, args);
+    wxString exe, args, wd;
+    GetExecutable(exe, args, wd);
     clEnvList_t envList = GetEnvList();
     clConsoleBase::Ptr_t console = clConsoleBase::GetTerminal();
     console->SetAutoTerminate(true);
     console->SetCommand(exe, args);
+    console->SetWorkingDirectory(wd);
     console->SetWaitWhenDone(true);
     console->SetSink(this);
     if(console->Start()) {
@@ -652,7 +678,7 @@ void clFileSystemWorkspace::OnStopExecute(clExecuteEvent& event)
 {
     CHECK_EVENT(event);
     if(m_execPID != wxNOT_FOUND) {
-        ::clKill(m_execPID, wxSIGTERM);
+        ::clKill(m_execPID, wxSIGTERM, true);
         m_execPID = wxNOT_FOUND;
     }
 }
@@ -734,11 +760,12 @@ void clFileSystemWorkspace::DoBuild(const wxString& target)
 
     wxString cmd = GetTargetCommand(target);
     if(cmd.IsEmpty()) {
-        ::wxMessageBox(_("Dont know how to run '") + target + "'", "CodeLite", wxICON_WARNING | wxCENTER);
+        ::wxMessageBox(_("Don't know how to run '") + target + "'", "CodeLite", wxICON_WARNING | wxCENTER);
         return;
     }
 
-    if(GetConfig()->IsRemoteEnabled()) {
+    // Check that the remote development is enabled AND remote build
+    if(GetConfig()->IsRemoteEnabled() && GetConfig()->IsRemoteBuild()) {
         // Launch a remote build process
         if(m_remoteBuilder && m_remoteBuilder->IsRunning()) {
             return;
@@ -763,7 +790,7 @@ void clFileSystemWorkspace::DoBuild(const wxString& target)
         } else {
             clCommandEvent e(wxEVT_SHELL_COMMAND_STARTED);
             EventNotifier::Get()->AddPendingEvent(e);
-            
+
             // Notify about build process started
             clBuildEvent eventStart(wxEVT_BUILD_STARTED);
             EventNotifier::Get()->AddPendingEvent(eventStart);
@@ -848,25 +875,42 @@ void clFileSystemWorkspace::OnFileSaved(clCommandEvent& event)
 
     if(GetConfig()->IsRemoteEnabled()) {
         const wxString& filename = event.GetFileName();
-        const wxString& account = GetConfig()->GetRemoteAccount();
-        const wxString& remotePath = GetConfig()->GetRemoteFolder();
 
-        wxString remoteFilePath;
+        // There are 2 cases where we don't want to trigger remote save:
+        // 1. if the file was opened by the sftp plugin, don't attempt to save it remotely
+        // it will be done by the sftp plugin. These files are marked with client data
+        // set with the "sftp" key
+        // 2. if the file is not located under our root folder -> don't attempt to save it
+        bool managedBySftp = false;
+        IEditor* editor = clGetManager()->FindEditor(filename);
+        if(editor && editor->GetClientData("sftp")) {
+            managedBySftp = true;
+        }
 
-        // Make the local file path relative to the workspace location
-        wxFileName fnLocalFile(event.GetFileName());
-        fnLocalFile.MakeRelativeTo(GetFileName().GetPath());
+        wxString rootPath = GetFileName().GetPath();
+        wxString filePath = wxFileName(filename).GetPath();
+        bool doRemoteSave = filePath.StartsWith(rootPath) && !managedBySftp;
 
-        remoteFilePath = fnLocalFile.GetFullPath(wxPATH_UNIX);
-        remoteFilePath.Prepend(remotePath + "/");
-        wxFileName fnRemoteFile(remoteFilePath);
+        if(doRemoteSave) {
+            wxString remoteFilePath;
+            const wxString& account = GetConfig()->GetRemoteAccount();
+            const wxString& remotePath = GetConfig()->GetRemoteFolder();
 
-        // Build the remote filename
-        clSFTPEvent eventSave(wxEVT_SFTP_SAVE_FILE);
-        eventSave.SetAccount(account);
-        eventSave.SetLocalFile(filename);
-        eventSave.SetRemoteFile(fnRemoteFile.GetFullPath(wxPATH_UNIX));
-        EventNotifier::Get()->QueueEvent(eventSave.Clone());
+            // Make the local file path relative to the workspace location
+            wxFileName fnLocalFile(event.GetFileName());
+            fnLocalFile.MakeRelativeTo(GetFileName().GetPath());
+
+            remoteFilePath = fnLocalFile.GetFullPath(wxPATH_UNIX);
+            remoteFilePath.Prepend(remotePath + "/");
+            wxFileName fnRemoteFile(remoteFilePath);
+
+            // Build the remote filename
+            clSFTPEvent eventSave(wxEVT_SFTP_SAVE_FILE);
+            eventSave.SetAccount(account);
+            eventSave.SetLocalFile(filename);
+            eventSave.SetRemoteFile(fnRemoteFile.GetFullPath(wxPATH_UNIX));
+            EventNotifier::Get()->QueueEvent(eventSave.Clone());
+        }
     }
 }
 
@@ -920,45 +964,61 @@ void clFileSystemWorkspace::OnDebug(clDebugEvent& event)
 
     // Setup the debug session
 
-    wxString exe, args;
-    GetExecutable(exe, args);
+    wxString exe, args, wd;
+    GetExecutable(exe, args, wd);
 
     // Start the debugger
-    DebugSessionInfo si;
-    si.debuggerPath = MacroManager::Instance()->Expand(dinfo.path, clGetManager(), "");
-    si.exeName = exe;
-    si.cwd = GetFileName().GetPath();
-    clGetManager()->GetBreakpoints(si.bpList);
+    DebugSessionInfo startup_info;
+    clDebuggerBreakpoint::Vec_t bpList;
+    startup_info.debuggerPath = MacroManager::Instance()->Expand(dinfo.path, clGetManager(), "");
+    startup_info.exeName = exe;
+    startup_info.cwd = wd;
+    startup_info.cmds = ::wxStringTokenize(dinfo.startupCommands, "\r\n", wxTOKEN_STRTOK);
+    clGetManager()->GetBreakpoints(bpList);
+    startup_info.bpList = bpList;
 
     // Start terminal (doesn't do anything under MSW)
     m_debuggerTerminal.Clear();
     m_debuggerTerminal.Launch(dbgr->GetName());
-    si.ttyName = m_debuggerTerminal.GetTty();
-    si.enablePrettyPrinting = dinfo.enableGDBPrettyPrinting;
+    startup_info.ttyName = m_debuggerTerminal.GetTty();
+    startup_info.enablePrettyPrinting = dinfo.enableGDBPrettyPrinting;
+
+    // Fire "starting" event
+    clDebugEvent eventStarting(wxEVT_DEBUG_STARTING);
+    eventStarting.SetClientData(&startup_info);
+    if(EventNotifier::Get()->ProcessEvent(eventStarting))
+        return;
+
+    // Check if any plugins provided us with new breakpoints
+    if(!eventStarting.GetBreakpoints().empty()) {
+        startup_info.bpList.swap(eventStarting.GetBreakpoints());
+    }
 
     // Get toolchain
     CompilerPtr cmp = GetCompiler();
     if(cmp && !cmp->GetTool("Debugger").empty()) {
-        si.debuggerPath = cmp->GetTool("Debugger");
+        startup_info.debuggerPath = cmp->GetTool("Debugger");
     }
-    dbgr->Start(si);
+    dbgr->Start(startup_info);
 
     // Notify that debug session started
     // this will ensure that the debug layout is loaded
     clDebugEvent eventStarted(wxEVT_DEBUG_STARTED);
-    eventStarted.SetClientData(&si);
+    eventStarted.SetClientData(&startup_info);
     EventNotifier::Get()->ProcessEvent(eventStarted);
     // Now run the debuggee
     dbgr->Run(args, "");
 }
 
-void clFileSystemWorkspace::GetExecutable(wxString& exe, wxString& args)
+void clFileSystemWorkspace::GetExecutable(wxString& exe, wxString& args, wxString& wd)
 {
     exe = GetConfig()->GetExecutable();
     args = GetConfig()->GetArgs();
+    wd = GetConfig()->GetWorkingDirectory().IsEmpty() ? GetFileName().GetPath() : GetConfig()->GetWorkingDirectory();
 
     exe = MacroManager::Instance()->Expand(exe, nullptr, wxEmptyString);
     args = MacroManager::Instance()->Expand(args, nullptr, wxEmptyString);
+    wd = MacroManager::Instance()->Expand(wd, nullptr, wxEmptyString);
 }
 
 CompilerPtr clFileSystemWorkspace::GetCompiler()
@@ -993,3 +1053,58 @@ void clFileSystemWorkspace::OnFileSystemUpdated(clFileSystemEvent& event)
         Parse(false);
     }
 }
+
+void clFileSystemWorkspace::CreateCompileFlagsFile()
+{
+    wxBusyCursor bc;
+    const wxFileName& filename = clFileSystemWorkspace::Get().GetFileName();
+    auto backticks_cache = clFileSystemWorkspace::Get().GetBackticksCache();
+
+    auto selectedConfig = m_settings.GetSelectedConfig();
+    // Create a compile flags from the following info:
+    // - Get list of folders from the current workspace
+    // - Any command that is displayed in the text box, expand it
+    // - Selected compiler paths
+    auto compilerOptions = selectedConfig->GetCompilerOptions(backticks_cache);
+    auto includes = selectedConfig->ExpandUserCompletionFlags(filename.GetPath(), backticks_cache, true);
+
+    wxString compile_flags_txt;
+    // Include the workspace path by default
+    wxString workspacePath = filename.GetPath();
+    ::WrapWithQuotes(workspacePath);
+
+    compile_flags_txt << "-I" << workspacePath << "\n";
+    for(const auto& s : includes) {
+        compile_flags_txt << s << "\n";
+    }
+
+    for(const auto& s : compilerOptions) {
+        compile_flags_txt << s << "\n";
+    }
+
+    if(!compile_flags_txt.empty()) {
+        // replace any placeholders
+        compile_flags_txt = MacroManager::Instance()->Expand(compile_flags_txt, nullptr, "", "");
+        wxFileName fnCompileFlags(filename);
+        fnCompileFlags.SetFullName("compile_flags.txt");
+        FileUtils::WriteFileContent(fnCompileFlags, compile_flags_txt, wxConvUTF8);
+
+        // Fire JSON Generated event
+        clCommandEvent eventCompileCommandsGenerated(wxEVT_COMPILE_COMMANDS_JSON_GENERATED);
+        EventNotifier::Get()->QueueEvent(eventCompileCommandsGenerated.Clone());
+        clDEBUG() << "File:" << fnCompileFlags << "generated" << clEndl;
+
+        wxString msg;
+        msg << _("Successfully generated file:\n") << fnCompileFlags.GetFullPath();
+        ::wxMessageBox(msg, "CodeLite");
+    }
+}
+
+wxString clFileSystemWorkspace::GetExcludeFolders() const
+{
+    clFileSystemWorkspaceConfig::Ptr_t conf = m_settings.GetSelectedConfig();
+    if(conf) {
+        return conf->GetExecludePaths();
+    }
+    return wxEmptyString;
+}
